==> boo_0.7.6.2237.orig.tar.gz: boo-0.7.6.2237/src/Boo.Lang.Compiler/Ast/Method.cs <==
﻿#region license
// Copyright (c) 2004, Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

using System;
using Boo.Lang.Compiler.Ast.Impl;

namespace Boo.Lang.Compiler.Ast
{	
	[System.Xml.Serialization.XmlInclude(typeof(Constructor))]
	[System.Xml.Serialization.XmlInclude(typeof(Destructor))]
	[Serializable]
	public class Method : MethodImpl
	{	
		public Method()
		{			
 		}
		
		public Method(LexicalInfo lexicalInfoProvider) : base(lexicalInfoProvider)
		{
		}
		
		public Method(string name)
		{
			Name = name;
		}
		
		public bool IsRuntime
		{
			get
			{
				return 
					MethodImplementationFlags.Runtime ==
						(_implementationFlags & MethodImplementationFlags.Runtime);
			}
		}
		
		public bool IsExtension
		{
			get
			{
				return
					MethodImplementationFlags.Extension ==
						(_implementationFlags & MethodImplementationFlags.Extension);
			}
		}
		
		override public TypeDefinition DeclaringType
		{
			get
			{
				if (null != ParentNode)
				{
					if (NodeType.Property == ParentNode.NodeType ||
						NodeType.Event == ParentNode.NodeType)
					{
						return (TypeDefinition)ParentNode.ParentNode;
					}					
				}
				return (TypeDefinition)ParentNode;
			}
		}
		
		override public void Accept(IAstVisitor visitor)
		{
			visitor.OnMethod(this);
		}
	}
}

==> boo_0.9.2.3383+dfsg.orig.tar.gz: boo-0.9.2.3383+dfsg/src/Boo.Lang.Compiler/Ast/Method.cs <==
﻿#region license
// Copyright (c) 2004, Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

using System;

namespace Boo.Lang.Compiler.Ast
{	
	[System.Xml.Serialization.XmlInclude(typeof(Constructor))]
	[System.Xml.Serialization.XmlInclude(typeof(Destructor))]
	public partial class Method
	{	
		public Method()
		{			
 		}
		
		public Method(LexicalInfo lexicalInfoProvider) : base(lexicalInfoProvider)
		{
		}
		
		public Method(string name)
		{
			Name = name;
		}
		
		public bool IsRuntime
		{
			get
			{
				return 
					MethodImplementationFlags.Runtime ==
						(_implementationFlags & MethodImplementationFlags.Runtime);
			}
		}
		
		override public TypeDefinition DeclaringType
		{
			get
			{
				if (null != ParentNode)
				{
					if (NodeType.Property == ParentNode.NodeType ||
						NodeType.Event == ParentNode.NodeType)
					{
						return (TypeDefinition)ParentNode.ParentNode;
					}					
				}
				return (TypeDefinition)ParentNode;
			}
		}
	}
}
